@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import
 
-from text.base import BaseTagger
+from textblob.base import BaseTagger
 from textblob_fr.fr import tag as pattern_tag
 
+
 class PatternTagger(BaseTagger):
 
     '''Tagger that uses the implementation in
@@ -13,4 +14,4 @@ class PatternTagger(BaseTagger):
 
     def tag(self, sentence, tokenize=True):
         '''Tag a string `sentence`.'''
-        return pattern_tag(sentence, tokenize)
\ No newline at end of file
+        return pattern_tag(sentence, tokenize)
